@@ -1,28 +1,21 @@
 #' uncompress corretto source
 #'
-#' @param os system os
 #' @param ... extra param
-#' @export
-crt_unc <- function(os, ...){
-  UseMethod("crt_unc")
-}
-
-crt_unc.default <- function(os){
-  stop("no method for ", class(os)[1L])
-}
-
-#' @importFrom zip unzip
-crt_unc.Windowsx86 <- function(os, ...){
-  zip::unzip(...)
-}
-
-crt_unc.Windowsx64 <- function(os, ...){
-  zip::unzip(...)
+crt_unc <- function(...){
+  if (grepl("Darwin", get_os())) {
+    macunc(...)
+  } else if (grepl("Windows", get_os())) {
+    utils::unzip(...)
+  } else if (grepl("Linux", get_os())) {
+    utils::untar(...)
+  } else {
+    stop("no method for ", get_os())
+  }
 }
 
 #' @importFrom askpass askpass
 #' @importFrom fs path
-crt_unc.Darwinx64 <- function(os, file_path, exdir, ...){
+macunc <- function(file_path, exdir, ...){
   pw <- askpass::askpass("Please enter your MacOS password for install java:")
   chk <- system_sudo_chk(pw, "echo") == 0
   while (!chk) {
